Resize

Enum Resize 

pub enum Resize {
    Fit(Option<FilterType>),
    Crop(Option<CropOptions>),
    Scale(Option<FilterType>),
}
Resize accounting for terminal FontSize.

Resizes images with FontSize grid boundaries.

Variants



Fit(Option<FilterType>)

Fit to a Size.

If the image width or height is smaller than the target size, the image will be resized maintaining proportions.

The FilterType (re-exported from the image crate) defaults to FilterType::Nearest.



Crop(Option<CropOptions>)

Crop to size.

If the width or height is smaller than the area, the image will be cropped. The behaviour is the same as using Image widget with the overhead of resizing, but some terminals might misbehave when overdrawing characters over graphics. For example, the sixel branch of Alacritty never draws text over a cell that is currently being rendered by some sixel sequence, not necessarily originating from the same cell.

The CropOptions defaults to clipping the bottom and the right sides.



Scale(Option<FilterType>)

Scale the image

Same as Resize::Fit except it resizes the image even if the image is smaller than the render area

Implementations

Source

impl Resize

pub fn resize( &self, image: &DynamicImage, font_size: FontSize, size: Size, background_color: Option<Rgba<u8>>, ) -> DynamicImage

Resize image::DynamicImage to fit into the Size or smaller.

pub fn size_for( &self, image: &DynamicImage, font_size: FontSize, available: Size, ) -> Size

Calculate the Size for the DynamicImage for available size after resizing.

pub fn natural_size(image: &DynamicImage, font_size: FontSize) -> Size

Calculate the “natural” Size needed to render the DynamicImage at the FontSize, without any resizing.