ProtocolType

Enum ProtocolType 

pub enum ProtocolType {
    Halfblocks,
    Sixel,
    Kitty,
    Iterm2,
}
Serde-friendly protocol-type enum for Picker.

Variants



Halfblocks



Sixel



Kitty



Iterm2

Implementations

Source

impl ProtocolType

pub fn next(&self) -> ProtocolType

Examples found in repository?
examples/demo/main.rs (line 175)
156    pub fn on_key(&mut self, c: char) -> bool {
157        match c {
158            'q' => {
159                self.should_quit = true;
160            }
161            't' => {
162                self.show_images = match self.show_images {
163                    ShowImages::All => ShowImages::Fixed,
164                    ShowImages::Fixed => ShowImages::Resized,
165                    ShowImages::Resized => ShowImages::All,
166                }
167            }
168            'i' => {
169                // Normally, we *never* would want to switch the detected protocol.
170                // This is for some debug session, where you want to test some other protocol than
171                // the detected.
172                // Changing "live" is also quite hazardous, as this will render some artifacts in
173                // between, or even trigger error messages, or crashes.
174                // If you need to "downgrade" e.g. to Halfblocks, then do it before any renders.
175                let next = self.picker.protocol_type().next();
176                self.picker.set_protocol_type(next);
177                self.reset_images();
178            }
179            'o' => {
180                let path = match self.image_source_path.to_str() {
181                    Some("./assets/Ada.png") => "./assets/Jenkins.png",
182                    Some("./assets/Jenkins.png") => "./assets/NixOS.png",
183                    _ => "./assets/Ada.png",
184                };
185                self.image_source = image::ImageReader::open(path).unwrap().decode().unwrap();
186                self.image_source_path = path.into();
187                self.reset_images();
188            }
189            'H' => {
190                if self.split_percent >= 10 {
191                    self.split_percent -= 10;
192                }
193            }
194            'L' => {
195                if self.split_percent <= 90 {
196                    self.split_percent += 10;
197                }
198            }
199            'h' => {
200                let (pos, _, _) = &mut self.image_sliced_position;
201                if pos.x > 0 {
202                    pos.x -= 1;
203                }
204            }
205            'j' => {
206                let (pos, _, _) = &mut self.image_sliced_position;
207                if let Some(viewport) = self.image_sliced_viewport
208                    && (pos.y < 0 || (pos.y as u16) < viewport.height.saturating_sub(1))
209                {
210                    pos.y += 1;
211                }
212            }
213            'k' => {
214                let (pos, _, _) = &mut self.image_sliced_position;
215                if pos.y > 0
216                    || pos.y.unsigned_abs() < self.image_sliced.size().height.saturating_sub(1)
217                {
218                    pos.y -= 1;
219                }
220            }
221            'l' => {
222                let (pos, _, _) = &mut self.image_sliced_position;
223                if let Some(viewport) = self.image_sliced_viewport
224                    && pos.x
225                        < (viewport
226                            .width
227                            .saturating_sub(self.image_sliced.size().width)
228                            as i16)
229                {
230                    pos.x += 1;
231                }
232            }
233            'a' => {
234                self.image_sliced_position.2 = !self.image_sliced_position.2;
235            }
236            _ => {
237                return false;
238            }
239        }
240        true
241    }