Struct StatefulProtocol

pub struct StatefulProtocol { /* private fields */ }
A stateful resizing image protocol for the crate::StatefulImage widget.

The [create::thread::ThreadImage] widget also uses this, and is the reason why resizing is split from rendering.

Implementations

Source

impl StatefulProtocol

pub fn new( source: ImageSource, font_size: FontSize, protocol_type: StatefulProtocolType, ) -> Self

pub fn protocol_type(&self) -> &StatefulProtocolType

pub fn protocol_type_owned(self) -> StatefulProtocolType

pub fn last_encoding_result(&mut self) -> Option<Result<(), Errors>>

This returns the latest Result returned when encoding, and none if there was no encoding since the last result read. It is encouraged but not required to handle it

pub fn background_color(&self) -> Rgba<u8>

pub fn resize_encode_render( &mut self, resize: &Resize, area: Rect, buf: &mut Buffer, )

Resize and encode if necessary, and render immediately.

This blocks the UI thread but requires neither threads nor async.

pub fn needs_resize(&mut self, resize: &Resize, area: Rect) -> Option<Rect>

Check if the current image state would need resizing (grow or shrink) for the given area.

This can be called by the UI thread to check if this StatefulProtocol should be sent off to some background thread/task to do the resizing and encoding, instead of rendering. The thread should then return the StatefulProtocol so that it can be rendered.protoco

pub fn resize_encode(&mut self, resize: &Resize, area: Rect)

Resize the image and encode it for rendering. The result should be stored statefully so that next call for the given area does not need to redo the work.

This can be done in a background thread, and the result is stored in this StatefulProtocol.

pub fn render(&mut self, area: Rect, buf: &mut Buffer)

Render the currently resized and encoded data to the buffer.

pub fn size_for(&self, resize: &Resize, area: Rect) -> Rect