Image

Struct Image 

pub struct Image<'a> { /* private fields */ }
Fixed size image widget that uses Protocol.

The widget does not react to area resizes. Its advantage lies in that the Protocol needs only one initial resize.

The image won’t render if it doesn’t fit, unless Image::allow_clipping has been set.

// let picker = Picker::from_query_studio()?;
let image = image::ImageReader::open("./assets/NixOS.png")?.decode()?;
let proto = picker.new_protocol(image, Size::new(20, 10), Resize::Fit(None))?;

terminal.draw(|f| {
    f.render_widget(Image::new(&proto), f.area());
});

Implementations

Source

impl<'a> Image<'a>

pub fn new(image: &'a Protocol) -> Self

Examples found in repository?
examples/demo/main.rs (line 363)
318fn ui(f: &mut Frame<'_>, app: &mut App) {
319    let outer_block = Block::default()
320        .borders(Borders::TOP)
321        .title(app.title.as_str());
322
323    let chunks = Layout::default()
324        .direction(Direction::Horizontal)
325        .constraints([
326            Constraint::Percentage(app.split_percent),
327            Constraint::Percentage(100 - app.split_percent),
328        ])
329        .split(outer_block.inner(f.area()));
330    f.render_widget(outer_block, f.area());
331
332    let left_chunks = vertical_layout().split(chunks[0]);
333    let right_chunks = vertical_layout().split(chunks[1]);
334
335    let chunks_left_top = Layout::default()
336        .direction(Direction::Horizontal)
337        .constraints([Constraint::Percentage(50), Constraint::Percentage(50)])
338        .split(left_chunks[0]);
339
340    let block_left_top = block("Fixed");
341    let area = block_left_top.inner(chunks_left_top[0]);
342    f.render_widget(
343        paragraph(app.background.as_str()).style(Color::Yellow),
344        area,
345    );
346    f.render_widget(block_left_top, chunks_left_top[0]);
347    if app.show_images != ShowImages::Resized {
348        // Let it be surrounded by styled text.
349        let area = Rect {
350            x: area.x + 1,
351            y: area.y + 1,
352            width: area.width.saturating_sub(2),
353            height: area.height.saturating_sub(2),
354        };
355
356        if let Some(placeholder_area) = app.image_static.needs_placeholder(area) {
357            let placeholder = Block::bordered()
358                .border_type(BorderType::QuadrantOutside)
359                .bg(Color::DarkGray);
360            f.render_widget(Clear {}, placeholder.inner(placeholder_area));
361            f.render_widget(placeholder, placeholder_area);
362        } else {
363            let image = Image::new(&app.image_static).allow_clipping(true);
364            f.render_widget(image, area);
365        }
366    }
367
368    let block_middle_top = block("Sliced");
369    let area = block_middle_top.inner(chunks_left_top[1]);
370    app.image_sliced_viewport = Some(area.into());
371    f.render_widget(
372        paragraph(app.background.as_str()).style(Color::LightBlue),
373        area,
374    );
375    f.render_widget(block_middle_top, chunks_left_top[1]);
376    if app.show_images != ShowImages::Resized {
377        let (pos, _, _) = app.image_sliced_position;
378        let image = SlicedImage::new(&app.image_sliced, pos);
379        f.render_widget(image, area);
380    }
381
382    let chunks_left_bottom = Layout::default()
383        .direction(Direction::Horizontal)
384        .constraints([Constraint::Percentage(50), Constraint::Percentage(50)])
385        .split(left_chunks[1]);
386
387    app.render_resized_image(f, Resize::Crop(None), chunks_left_bottom[0]);
388    app.render_resized_image(f, Resize::Scale(None), chunks_left_bottom[1]);
389    app.render_resized_image(f, Resize::Fit(None), right_chunks[0]);
390
391    let block_right_bottom = block("Help");
392    let area = block_right_bottom.inner(right_chunks[1]);
393    f.render_widget(
394        paragraph(vec![
395            Line::from(format!(
396                "Font size: {}×{}",
397                app.picker.font_size().width,
398                app.picker.font_size().height
399            )),
400            Line::from(format!("Protocol: {:?}", app.picker.protocol_type())),
401            Line::from("Key bindings:"),
402            Line::from(vec![
403                Span::from("H").green(),
404                Span::from("/"),
405                Span::from("L").green(),
406                Span::from(": resize panes"),
407            ]),
408            Line::from(vec![Span::from("o").green(), Span::from(": cycle image")]),
409            Line::from(vec![
410                Span::from("t").green(),
411                Span::from(format!(": toggle ({:?})", app.show_images)),
412            ]),
413            Line::from(vec![
414                Span::from("h").green(),
415                Span::from("/"),
416                Span::from("j").green(),
417                Span::from("/"),
418                Span::from("k").green(),
419                Span::from("/"),
420                Span::from("l").green(),
421                Span::from(": move"),
422            ]),
423            Line::from(vec![
424                Span::from("a").green(),
425                Span::from(": toggle animation"),
426            ]),
427        ]),
428        area,
429    );
430    f.render_widget(block_right_bottom, right_chunks[1]);
431}
pub fn allow_clipping(self, allow: bool) -> Self

Allow clipping the image if the render area is smaller than the image, and if the protocol supports it (protocol::kitty and protocol::halfblocks).

This is disabled by default to make the behavior consistent.

See also protocol::Protocol::needs_placeholder, which is an excellent complement if you need to render something when the image couldn’t.

terminal.draw(|f| {
    if let Some(placeholder_area) = proto.needs_placeholder(f.area()) {
        // Render `Box` or something with placeholder_area.
    } else {
        f.render_widget(Image::new(&proto).allow_clipping(true), f.area());
    }
});
Examples found in repository?
examples/demo/main.rs (line 363)
318fn ui(f: &mut Frame<'_>, app: &mut App) {
319    let outer_block = Block::default()
320        .borders(Borders::TOP)
321        .title(app.title.as_str());
322
323    let chunks = Layout::default()
324        .direction(Direction::Horizontal)
325        .constraints([
326            Constraint::Percentage(app.split_percent),
327            Constraint::Percentage(100 - app.split_percent),
328        ])
329        .split(outer_block.inner(f.area()));
330    f.render_widget(outer_block, f.area());
331
332    let left_chunks = vertical_layout().split(chunks[0]);
333    let right_chunks = vertical_layout().split(chunks[1]);
334
335    let chunks_left_top = Layout::default()
336        .direction(Direction::Horizontal)
337        .constraints([Constraint::Percentage(50), Constraint::Percentage(50)])
338        .split(left_chunks[0]);
339
340    let block_left_top = block("Fixed");
341    let area = block_left_top.inner(chunks_left_top[0]);
342    f.render_widget(
343        paragraph(app.background.as_str()).style(Color::Yellow),
344        area,
345    );
346    f.render_widget(block_left_top, chunks_left_top[0]);
347    if app.show_images != ShowImages::Resized {
348        // Let it be surrounded by styled text.
349        let area = Rect {
350            x: area.x + 1,
351            y: area.y + 1,
352            width: area.width.saturating_sub(2),
353            height: area.height.saturating_sub(2),
354        };
355
356        if let Some(placeholder_area) = app.image_static.needs_placeholder(area) {
357            let placeholder = Block::bordered()
358                .border_type(BorderType::QuadrantOutside)
359                .bg(Color::DarkGray);
360            f.render_widget(Clear {}, placeholder.inner(placeholder_area));
361            f.render_widget(placeholder, placeholder_area);
362        } else {
363            let image = Image::new(&app.image_static).allow_clipping(true);
364            f.render_widget(image, area);
365        }
366    }
367
368    let block_middle_top = block("Sliced");
369    let area = block_middle_top.inner(chunks_left_top[1]);
370    app.image_sliced_viewport = Some(area.into());
371    f.render_widget(
372        paragraph(app.background.as_str()).style(Color::LightBlue),
373        area,
374    );
375    f.render_widget(block_middle_top, chunks_left_top[1]);
376    if app.show_images != ShowImages::Resized {
377        let (pos, _, _) = app.image_sliced_position;
378        let image = SlicedImage::new(&app.image_sliced, pos);
379        f.render_widget(image, area);
380    }
381
382    let chunks_left_bottom = Layout::default()
383        .direction(Direction::Horizontal)
384        .constraints([Constraint::Percentage(50), Constraint::Percentage(50)])
385        .split(left_chunks[1]);
386
387    app.render_resized_image(f, Resize::Crop(None), chunks_left_bottom[0]);
388    app.render_resized_image(f, Resize::Scale(None), chunks_left_bottom[1]);
389    app.render_resized_image(f, Resize::Fit(None), right_chunks[0]);
390
391    let block_right_bottom = block("Help");
392    let area = block_right_bottom.inner(right_chunks[1]);
393    f.render_widget(
394        paragraph(vec![
395            Line::from(format!(
396                "Font size: {}×{}",
397                app.picker.font_size().width,
398                app.picker.font_size().height
399            )),
400            Line::from(format!("Protocol: {:?}", app.picker.protocol_type())),
401            Line::from("Key bindings:"),
402            Line::from(vec![
403                Span::from("H").green(),
404                Span::from("/"),
405                Span::from("L").green(),
406                Span::from(": resize panes"),
407            ]),
408            Line::from(vec![Span::from("o").green(), Span::from(": cycle image")]),
409            Line::from(vec![
410                Span::from("t").green(),
411                Span::from(format!(": toggle ({:?})", app.show_images)),
412            ]),
413            Line::from(vec![
414                Span::from("h").green(),
415                Span::from("/"),
416                Span::from("j").green(),
417                Span::from("/"),
418                Span::from("k").green(),
419                Span::from("/"),
420                Span::from("l").green(),
421                Span::from(": move"),
422            ]),
423            Line::from(vec![
424                Span::from("a").green(),
425                Span::from(": toggle animation"),
426            ]),
427        ]),
428        area,
429    );
430    f.render_widget(block_right_bottom, right_chunks[1]);
431}